@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Xan Lopez
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: downloader-view.c,v 1.41 2003/12/21 12:55:56 xan Exp $
+ *  $Id: downloader-view.c,v 1.47 2004/01/24 09:56:42 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -155,7 +156,14 @@ downloader_view_class_init (DownloaderViewClass *klass)
 static void
 status_icon_activated (EggStatusIcon *icon, DownloaderView *dv)
 {
-	gtk_window_present (GTK_WINDOW (dv->priv->window));
+	if (GTK_WIDGET_VISIBLE (dv->priv->window))
+	{
+		gtk_widget_hide (dv->priv->window);
+	}
+	else
+	{
+		gtk_window_present (GTK_WINDOW (dv->priv->window));
+	}
 }
 
 static void
@@ -202,8 +210,9 @@ downloader_view_finalize (GObject *object)
 DownloaderView *
 downloader_view_new (void)
 {
-	return EPHY_DOWNLOADER_VIEW (g_object_new
-			(EPHY_TYPE_DOWNLOADER_VIEW, NULL));
+	return EPHY_DOWNLOADER_VIEW (g_object_new (EPHY_TYPE_DOWNLOADER_VIEW,
+			 			   "persist-position", TRUE,
+			 			   NULL));
 }
 
 static char *
@@ -329,24 +338,45 @@ seconds_remaining_total (EphyDownload *download, gpointer data, DownloaderView *
 static void
 update_status_icon (DownloaderView *dv)
 {
-	char *tooltip, *remaining;
-	int downloads;
+	char *tooltip, *downloadstring, *remainingstring;
+	int downloads, remaining;
 
 	dv->priv->remaining_secs = 0;
 	g_hash_table_foreach (dv->priv->downloads_hash,
 			      (GHFunc) seconds_remaining_total, dv);
 	
-	remaining = format_interval (dv->priv->remaining_secs);
+	remaining = (dv->priv->remaining_secs);
+
+	if (remaining < 60)
+	{
+		remainingstring = g_strdup_printf (ngettext ("About %d second left",
+					"About %d seconds left", remaining),
+					remaining);
+	}
+	else
+	{
+		remaining /= 60;
+		
+		remainingstring = g_strdup_printf (ngettext ("About %d minute left",
+					"About %d minutes left", remaining),
+					remaining);
+	}
+
 	downloads = g_hash_table_size (dv->priv->downloads_hash);
-	tooltip = g_strdup_printf ("%d downloads, with a total of "
-				   "%s minutes remaining",
-				   downloads, remaining);
+
+	downloadstring = g_strdup_printf (ngettext ("%d download", 
+					"%d downloads", downloads), 
+					downloads);
+
+	tooltip = g_strdup_printf ("%s\n%s",
+					downloadstring, remainingstring);
 
 	egg_status_icon_set_tooltip (dv->priv->status_icon,
 				     tooltip, NULL);
 
 	g_free (tooltip);
-	g_free (remaining);
+	g_free (downloadstring);
+	g_free (remainingstring);
 }
 
 static void
@@ -405,8 +435,9 @@ downloader_view_build_ui (DownloaderView *dv)
 
 	ephy_dialog_construct (d,
                                properties,
-                               "epiphany.glade",
-                               "download_manager_dialog");
+			       ephy_file ("epiphany.glade"),
+                               "download_manager_dialog",
+			       NULL);
 
 	/* lookup needed widgets */
 	priv->window = ephy_dialog_get_control(d, properties[PROP_WINDOW].id);
@@ -498,12 +529,12 @@ download_dialog_pause_cb (GtkButton *button, DownloaderView *dv)
 	if (state == EPHY_DOWNLOAD_DOWNLOADING)
 	{
 		ephy_download_pause (download);
-		gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), _("Resume"));
+		gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), _("_Resume"));
 	}
 	else if (state == EPHY_DOWNLOAD_PAUSED)
 	{
 		ephy_download_resume (download);
-		gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), _("Pause"));
+		gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), _("_Pause"));
 	}
 }
 
@@ -562,6 +593,8 @@ downloader_view_remove_download (DownloaderView *dv, EphyDownload *download)
 		gtk_tree_row_reference_free (row_ref);
 	}
 
+	update_status_icon (dv);
+
 	/* Close the dialog if there are no more downloads */
 
 	if (!g_hash_table_size (dv->priv->downloads_hash))
