@@ -15,9 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: mozilla-download.cpp,v 1.4 2003/12/21 12:55:57 xan Exp $
+ * $Id: mozilla-download.cpp,v 1.5 2004/01/10 16:36:43 chpe Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "mozilla-download.h"
 
 #include "nsString.h"
