@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.h,v 1.7 2003/05/19 19:46:32 Bordoley Exp $
+ *  $Id: ephy-stock-icons.h,v 1.10 2003/12/13 22:04:02 chpe Exp $
  */
 
 #ifndef EPHY_STOCK_ICONS_H
@@ -27,14 +27,16 @@ G_BEGIN_DECLS
 #define EPHY_STOCK_UNSECURE        "epiphany-unsecure"
 #define EPHY_STOCK_HISTORY         "epiphany-history"
 #define EPHY_STOCK_BOOKMARKS       "epiphany-bookmarks"
-#define EPHY_STOCK_BOOKMARK_PAGE   "epiphany-bookmark-page"
-#define EPHY_STOCK_NEW_TAB         "epiphany-new-tab"
-#define EPHY_STOCK_FULLSCREEN      "epiphany-fullscreen"
-#define EPHY_STOCK_VIEWSOURCE      "epiphany-viewsource"
-#define EPHY_STOCK_SEND_LINK       "epiphany-send-link"
 #define EPHY_STOCK_ENTRY	   "epiphany-entry"
 #define EPHY_STOCK_DOWNLOAD	   "epiphany-download"
 
+#define STOCK_NEW_TAB		   "stock_new-tab"
+#define STOCK_FULLSCREEN	   "stock_fullscreen"
+#define STOCK_VIEW_SOURCE	   "stock_view-html-source"
+#define STOCK_SEND_MAIL		   "stock_mail_send"
+#define STOCK_ADD_BOOKMARK	   "stock_add-bookmark"
+#define STOCK_PRINT_SETUP	   "stock_print-setup"
+
 void ephy_stock_icons_init (void);
 
 G_END_DECLS
