@@ -16,11 +16,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.26 2003/11/05 22:56:14 chpe Exp $
+ *  $Id: ephy-notebook.c,v 1.30 2004/01/10 16:11:18 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "ephy-notebook.h"
@@ -92,13 +92,14 @@ enum
 	TAB_REMOVED,
 	TABS_REORDERED,
 	TAB_DETACHED,
+	TAB_DELETE,
 	LAST_SIGNAL
 };
 
-static GObjectClass *parent_class = NULL;
-
 static guint signals[LAST_SIGNAL] = { 0 };
 
+static GObjectClass *parent_class = NULL;
+
 GType
 ephy_notebook_get_type (void)
 {
@@ -175,6 +176,16 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
+	signals[TAB_DELETE] =
+		g_signal_new ("tab_delete",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EphyNotebookClass, tab_delete),
+			      g_signal_accumulator_true_handled, NULL,
+			      ephy_marshal_BOOLEAN__OBJECT,
+			      G_TYPE_BOOLEAN,
+			      1,
+			      GTK_TYPE_WIDGET);
 
 	g_type_class_add_private (object_class, sizeof(EphyNotebookPrivate));
 }
@@ -623,6 +634,8 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 
 	g_signal_stop_emission_by_name (widget, "drag_data_received");
 
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_ARBITRARY_URL)) return;
+
 	if (selection_data->length <= 0 || selection_data->data == NULL) return;
 
 	if (selection_data->target == gdk_atom_intern (EPHY_DND_URL_TYPE, FALSE))
@@ -654,7 +667,7 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 	if (child)
 	{
 		embed = EPHY_EMBED (child);
-		tab = EPHY_TAB (g_object_get_data (G_OBJECT (embed), "EphyTab"));
+		tab = ephy_tab_for_embed (embed);
 	}
 
 	l = uris;
@@ -773,6 +786,8 @@ ephy_notebook_finalize (GObject *object)
 	g_object_unref (notebook->priv->title_tips);
 
 	LOG ("EphyNotebook finalised %p", object)
+
+	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 static void
@@ -852,9 +867,15 @@ static void
 close_button_clicked_cb (GtkWidget *widget, GtkWidget *child)
 {
 	EphyNotebook *notebook;
+	gboolean inhibited = FALSE;
 
 	notebook = EPHY_NOTEBOOK (gtk_widget_get_parent (child));
-	ephy_notebook_remove_page (notebook, child);
+	g_signal_emit (G_OBJECT (notebook), signals[TAB_DELETE], 0, child, &inhibited);
+
+	if (inhibited == FALSE)
+	{
+		ephy_notebook_remove_page (notebook, child);
+	}
 }
 
 static GtkWidget *
@@ -958,7 +979,7 @@ ephy_notebook_insert_page (EphyNotebook *nb,
 	GtkWidget *label;
 
 	g_return_if_fail (EPHY_IS_EMBED (child));
-	tab = EPHY_TAB (g_object_get_data (G_OBJECT (child), "EphyTab"));
+	tab = ephy_tab_for_embed (EPHY_EMBED (child));
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	label = build_tab_label (nb, child);
@@ -1051,7 +1072,7 @@ smart_tab_switching_on_closure (EphyNotebook *nb,
 
 void
 ephy_notebook_remove_page (EphyNotebook *nb,
-			  GtkWidget *child)
+			   GtkWidget *child)
 {
 	int num, position, curr;
 	EphyTab *tab;
@@ -1060,7 +1081,7 @@ ephy_notebook_remove_page (EphyNotebook *nb,
 	g_return_if_fail (EPHY_IS_NOTEBOOK (nb));
 	g_return_if_fail (EPHY_IS_EMBED (child));
 
-	tab = EPHY_TAB (g_object_get_data (G_OBJECT (child), "EphyTab"));
+	tab = ephy_tab_for_embed (EPHY_EMBED (child));
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	num = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
