@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.104 2004/01/09 09:29:56 chpe Exp $
+ *  $Id: window-commands.c,v 1.106 2004/01/22 23:17:34 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -270,7 +270,7 @@ window_cmd_view_reload (GtkAction *action,
 	ephy_embed_activate (embed);
 
 	ephy_embed_reload (embed, force ? EMBED_RELOAD_NORMAL
-					: EMBED_RELOAD_BYPASSCACHE);
+					: EMBED_RELOAD_FORCE);
 }
 
 void
@@ -689,7 +689,7 @@ save_source_completed_cb (EphyEmbedPersist *persist)
 	dest = ephy_embed_persist_get_dest (persist);
 	g_return_if_fail (dest != NULL);
 
-	ephy_shell_delete_on_exit (ephy_shell, dest);
+	ephy_file_delete_on_exit (dest);
 
 	editor_open_uri (dest);
 }
@@ -737,9 +737,20 @@ save_temp_source (EphyEmbed *embed)
 	char *tmp, *base;
 	EphyEmbedPersist *persist;
 
-	base = g_build_filename (g_get_tmp_dir (), "viewsourceXXXXXX", NULL);
+	char *static_temp_dir;
+
+	static_temp_dir = ephy_file_tmp_directory ();
+	if (static_temp_dir == NULL)
+	{
+		return;
+	}
+	base = g_build_filename (static_temp_dir, "viewsourceXXXXXX", NULL);
 	tmp = ephy_file_tmp_filename (base, "html");
 	g_free (base);
+	if (tmp == NULL)
+	{
+		return;
+	}
 
 	persist = EPHY_EMBED_PERSIST
 		(ephy_embed_factory_new_object ("EphyEmbedPersist"));
